==> simple_toasts-1.0.x-dev.tar.gz: simple_toasts/src/Form/SimpleToastsSettingsForm.php <==
<?php

namespace Drupal\simple_toasts\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Extension\ThemeHandlerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure Simple Toasts general settings.
 */
class SimpleToastsSettingsForm extends ConfigFormBase {

  /**
   * The theme handler.
   *
   * @var \Drupal\Core\Extension\ThemeHandlerInterface
   */
  protected ThemeHandlerInterface $themeHandler;

  /**
   * Constructs a \Drupal\system\ConfigFormBase object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   * @param \Drupal\Core\Extension\ThemeHandlerInterface $theme_handler
   *   The theme handler.
   */
  public function __construct(ConfigFactoryInterface $config_factory, ThemeHandlerInterface $theme_handler) {
    parent::__construct($config_factory);
    $this->themeHandler = $theme_handler;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('theme_handler')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'simple_toasts_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return [
      'simple_toasts.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config('simple_toasts.settings');

    $form['themes'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Themes'),
      '#description' => $this->t('Define the themes that should use toast messages.'),
      '#options' => $this->getThemeOptions(),
      '#default_value' => $config->get('themes') ?: [$this->themeHandler->getDefault()],
      '#required' => TRUE,
    ];

    $form['position'] = [
      '#type' => 'select',
      '#title' => $this->t('Message Position'),
      '#description' => $this->t('The position of the messages on the screen.'),
      '#default_value' => $config->get('position'),
      '#options' => [
        'top-right' => $this->t('Top Right'),
        'top-center' => $this->t('Top Center'),
        'top-left' => $this->t('Top Left'),
        'bottom-right' => $this->t('Bottom Right'),
        'bottom-center' => $this->t('Bottom Center'),
        'bottom-left' => $this->t('Bottom Left'),
      ],
    ];

    $form['duration'] = [
      '#type' => 'details',
      '#title' => $this->t('Duration'),
      '#open' => TRUE,
    ];

    $form['duration']['status_duration'] = [
      '#type' => 'number',
      '#title' => $this->t('Status message duration'),
      '#default_value' => $config->get('status_duration'),
      '#size' => 40,
      '#description' => $this->t('The duration in milliseconds before status messages disappear. Set to 0 to disable auto-dismiss.'),
    ];
    $form['duration']['warning_duration'] = [
      '#type' => 'number',
      '#title' => $this->t('Warning message duration'),
      '#default_value' => $config->get('warning_duration'),
      '#size' => 40,
      '#description' => $this->t('The duration in milliseconds before warning messages disappear. Set to 0 to disable auto-dismiss.'),
    ];
    $form['duration']['error_duration'] = [
      '#type' => 'number',
      '#title' => $this->t('Error message duration'),
      '#default_value' => $config->get('error_duration'),
      '#size' => 40,
      '#description' => $this->t('The duration in milliseconds before error messages disappear. Set to 0 to disable auto-dismiss.'),
    ];

    $form['animation'] = [
      '#type' => 'details',
      '#title' => $this->t('Animation'),
      '#open' => TRUE,
    ];

    $form['animation']['animation_in'] = [
      '#type' => 'select',
      '#title' => $this->t('Animation in'),
      '#default_value' => $config->get('animation_in'),
      '#description' => $this->t('Animate the toast in.'),
      '#options' => [
        'fade-in' => $this->t('Fade'),
        'slide-in' => $this->t('Slide'),
        'none' => $this->t('None'),
      ],
    ];

    $form['animation']['animation_out'] = [
      '#type' => 'select',
      '#title' => $this->t('Animation out'),
      '#default_value' => $config->get('animation_out'),
      '#description' => $this->t('Animate the toast out.'),
      '#options' => [
        'fade-out' => $this->t('Fade'),
        'slide-out' => $this->t('Slide'),
        'none' => $this->t('None'),
      ],
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->configFactory->getEditable('simple_toasts.settings')
      ->set('themes', $form_state->getValue('themes'))
      ->set('position', $form_state->getValue('position'))
      ->set('status_duration', $form_state->getValue('status_duration'))
      ->set('warning_duration', $form_state->getValue('warning_duration'))
      ->set('error_duration', $form_state->getValue('error_duration'))
      ->set('animation_in', $form_state->getValue('animation_in'))
      ->set('animation_out', $form_state->getValue('animation_out'))
      ->save();

    parent::submitForm($form, $form_state);
  }

  /**
   * Return an array with all the themes.
   *
   * @return array
   *   An array with all the themes.
   */
  protected function getThemeOptions(): array {
    $output = [];
    foreach ($this->themeHandler->listInfo() as $key => $value) {
      $output[$key] = $value->getName();
    }
    return $output;
  }

}

==> simple_toasts-1.1.x-dev.tar.gz: simple_toasts/src/Form/SimpleToastsSettingsForm.php <==
<?php

namespace Drupal\simple_toasts\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Config\TypedConfigManagerInterface;
use Drupal\Core\Extension\ThemeHandlerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure Simple Toasts general settings.
 */
class SimpleToastsSettingsForm extends ConfigFormBase {

  /**
   * The theme handler.
   *
   * @var \Drupal\Core\Extension\ThemeHandlerInterface
   */
  protected ThemeHandlerInterface $themeHandler;

  /**
   * Constructs a \Drupal\system\ConfigFormBase object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   * @param \Drupal\Core\Config\TypedConfigManagerInterface $typed_config_manager
   *  The typed configuration manager.
   * @param \Drupal\Core\Extension\ThemeHandlerInterface $theme_handler
   *   The theme handler.
   */
  public function __construct(ConfigFactoryInterface $config_factory, TypedConfigManagerInterface $typed_config_manager, ThemeHandlerInterface $theme_handler) {
    parent::__construct($config_factory, $typed_config_manager);
    $this->themeHandler = $theme_handler;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('config.typed'),
      $container->get('theme_handler')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'simple_toasts_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return [
      'simple_toasts.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config('simple_toasts.settings');

    $form['themes'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Themes'),
      '#description' => $this->t('Define the themes that should use toast messages.'),
      '#options' => $this->getThemeOptions(),
      '#default_value' => $config->get('themes') ?: [$this->themeHandler->getDefault()],
      '#required' => FALSE,
    ];

    $form['position'] = [
      '#type' => 'select',
      '#title' => $this->t('Message Position'),
      '#description' => $this->t('The position of the messages on the screen.'),
      '#default_value' => $config->get('position'),
      '#options' => [
        'top-right' => $this->t('Top Right'),
        'top-center' => $this->t('Top Center'),
        'top-left' => $this->t('Top Left'),
        'bottom-right' => $this->t('Bottom Right'),
        'bottom-center' => $this->t('Bottom Center'),
        'bottom-left' => $this->t('Bottom Left'),
      ],
    ];

    $form['duration'] = [
      '#type' => 'details',
      '#title' => $this->t('Duration'),
      '#open' => TRUE,
    ];

    $form['duration']['status_duration'] = [
      '#type' => 'number',
      '#title' => $this->t('Status message duration'),
      '#default_value' => $config->get('status_duration'),
      '#size' => 40,
      '#description' => $this->t('The duration in milliseconds before status messages disappear. Set to 0 to disable auto-dismiss.'),
    ];
    $form['duration']['warning_duration'] = [
      '#type' => 'number',
      '#title' => $this->t('Warning message duration'),
      '#default_value' => $config->get('warning_duration'),
      '#size' => 40,
      '#description' => $this->t('The duration in milliseconds before warning messages disappear. Set to 0 to disable auto-dismiss.'),
    ];
    $form['duration']['error_duration'] = [
      '#type' => 'number',
      '#title' => $this->t('Error message duration'),
      '#default_value' => $config->get('error_duration'),
      '#size' => 40,
      '#description' => $this->t('The duration in milliseconds before error messages disappear. Set to 0 to disable auto-dismiss.'),
    ];

    $form['animation'] = [
      '#type' => 'details',
      '#title' => $this->t('Animation'),
      '#open' => TRUE,
    ];

    $form['animation']['animation_in'] = [
      '#type' => 'select',
      '#title' => $this->t('Animation in'),
      '#default_value' => $config->get('animation_in'),
      '#description' => $this->t('Animate the toast in.'),
      '#options' => [
        'fade-in' => $this->t('Fade'),
        'slide-in' => $this->t('Slide'),
        'none' => $this->t('None'),
      ],
    ];

    $form['animation']['animation_out'] = [
      '#type' => 'select',
      '#title' => $this->t('Animation out'),
      '#default_value' => $config->get('animation_out'),
      '#description' => $this->t('Animate the toast out.'),
      '#options' => [
        'fade-out' => $this->t('Fade'),
        'slide-out' => $this->t('Slide'),
        'none' => $this->t('None'),
      ],
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->configFactory->getEditable('simple_toasts.settings')
      ->set('themes', $form_state->getValue('themes'))
      ->set('position', $form_state->getValue('position'))
      ->set('status_duration', $form_state->getValue('status_duration'))
      ->set('warning_duration', $form_state->getValue('warning_duration'))
      ->set('error_duration', $form_state->getValue('error_duration'))
      ->set('animation_in', $form_state->getValue('animation_in'))
      ->set('animation_out', $form_state->getValue('animation_out'))
      ->save();

    parent::submitForm($form, $form_state);
  }

  /**
   * Return an array with all the themes.
   *
   * @return array
   *   An array with all the themes.
   */
  protected function getThemeOptions(): array {
    $output = [];
    foreach ($this->themeHandler->listInfo() as $key => $value) {
      $output[$key] = $value->getName();
    }
    return $output;
  }

}
